@@ -5,6 +5,7 @@
 # yanto : 730988759
 # kenkan : 1607338903
 # kyy : 1663258664
+# riz : 951454060
 
 DEVS = [
     1191668125,
@@ -15,6 +16,7 @@ DEVS = [
     1607338903,
     1663258664,
     901878554,
+    951454060,
 ]
 
 # jangan hapus grup && gua gban lo
