@@ -13,3 +13,6 @@ from .call import *
 from .sticker import *
 from .what import *
 from .content import *
+from .check_size import *
+from .dl_helpers import *
+from .clear_string import *
