@@ -4,6 +4,8 @@ import os
 import shlex
 from typing import Tuple
 from io import BytesIO
+from PIL import Image
+from PIL import *
 
 from pyrogram.errors.exceptions.bad_request_400 import (
     ChatAdminRequired,
@@ -91,14 +93,6 @@ async def tg_lock(
     )
 
 
-async def make_carbon(code):
-    url = "https://carbonara.vercel.app/api/cook"
-    async with aiosession.post(url, json={"code": code}) as resp:
-        image = BytesIO(await resp.read())
-    image.name = "carbon.png"
-    return image
-
-
 def get_text(message: Message) -> [None, str]:
     """Extract Text From Commands"""
     text_to_return = message.text
